@@ -1,7 +1,7 @@
 ;;; aidermacs.el --- AI pair programming with Aider -*- lexical-binding: t; -*-
 ;; Author: Mingde (Matthew) Zeng <matthewzmd@posteo.net>
-;; Package-Version: 20251017.611
-;; Package-Revision: 7fb9f4859c23
+;; Package-Version: 20251020.2027
+;; Package-Revision: 14238322a636
 ;; Package-Requires: ((emacs "26.1") (transient "0.3.0") (compat "30.0.2.0") (markdown-mode "2.7"))
 ;; Keywords: ai emacs llm aider ai-pair-programming tools
 ;; URL: https://github.com/MatthewZMD/aidermacs
@@ -176,8 +176,8 @@ Uses cached version if available to avoid repeated process calls."
                 (when (= 0 (process-file aidermacs-program nil t nil "--version"))
                   (goto-char (point-min))
                   (when (re-search-forward
-                         (concat aidermacs-program " \\([0-9]+\\.[0-9]+\\.[0-9]+\\)") nil t)
-                    (match-string 1)))))))
+                         "\\([0-9]+\\.[0-9]+\\.[0-9]+\\)" nil t)
+                    (match-string 0)))))))
   (message "Aider version %s" aidermacs--cached-version)
   aidermacs--cached-version)
 
